#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

/* system skins directory */
#undef GQMPEG_SKINDIR

/* define this to enable japanese ID3 tags */
#undef ENABLE_JAPANESE_TAGS

#undef ENABLE_RUSSIAN_TAGS

#undef HAVE_LIBMIKMOD

#undef HAVE_LIBPNG

#undef HAVE_VIDEO4LINUX

#undef HAVE_OSFMME

#undef HAVE_XF86_KEYSYMS

